California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 88 - EDUCATION FUNDING. REAL PROPERTY PARCEL TAX. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1283706 | YES ON 88: TAXPAYERS FOR BETTER SCHOOLS AND SMALLER CLASSES, SPONSORED BY EDVOICE, INC. | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1287075 | CALIFORNIANS AGAINST THE STATEWIDE PARCEL PROPERTY TAX, NO ON 88; NO NEW TAXES COMMITTEE, A PROJECT OF THE HOWARD JARVIS TAXPAYERS ASSOCIATION; SMALL BUSINESS ACTION COMMITTEE PAC | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | OPPOSE